Calculate the basal area of a tree given the diameter at breast height (dbh)
Source:R/Processes.R
BA_stem.RdThis function calculates the basal area of a tree given the diameter at breast height (dbh).
Examples
dbh = torch::torch_tensor(50)
basal_area = BA_stem(dbh)
print(basal_area)
#> torch_tensor
#> 0.1963
#> [ CPUFloatType{1} ]