This function generates random numbers from a uniform distribution with specified low and high values and size similar to np.random.uniform in Python.
Examples
np_runif(0, 1, c(2, 3))
#> [,1] [,2] [,3]
#> [1,] 0.6775706 0.1029247 0.24608773
#> [2,] 0.5726334 0.8998250 0.04205953